@@ -39,10 +39,10 @@ time_to_logcount <- function(model, log_count) {
 
     if (is.IsothermalGrowth(model)) {
         approx(model$simulation$logN, model$simulation$time,
-               log_count)$y
+               log_count, ties = "ordered")$y
     } else if(is.DynamicGrowth(model)) {
         approx(model$simulation$logN, model$simulation$time,
-               log_count)$y
+               log_count, ties = "ordered")$y
     } else {
         stop("Model not supported")
     }
@@ -74,15 +74,19 @@ time_to_logcount <- function(model, log_count) {
 #' \donttest{
 #' ## We need an instance of StochasticGrowth
 #'
-#' my_model <- "Trilinear"
+#' my_model <- "modGompertz"
 #' my_times <- seq(0, 30, length = 100)
 #' n_sims <- 3000
-#'
-#' stoc_growth <- predict_stochastic_growth(my_model, my_times, n_sims,
-#'     mean_logN0 = 0, sd_logN0 = .2,
-#'     mean_sqmu = 2,sd_sqmu = .3,
-#'     mean_sqlambda = 4, sd_sqlambda = .4,
-#'     mean_logNmax = 6, sd_logNmax = .5)
+#' 
+#' pars <- tribble(
+#'     ~par, ~mean, ~sd, ~scale,
+#'     "logN0", 0, .2, "original",
+#'     "mu", 2, .3, "sqrt",
+#'     "lambda", 4, .4, "sqrt",
+#'     "C", 6, .5, "original"
+#' )
+#' 
+#' stoc_growth <- predict_stochastic_growth(my_model, my_times, n_sims, pars)
 #'
 #' ## We can now call the function
 #'
