@@ -49,9 +49,12 @@ head(example_env_conditions)
 data("example_dynamic_growth")
 head(example_dynamic_growth)
 
+## -----------------------------------------------------------------------------
+data("growth_salmonella")
+head(growth_salmonella)
+
 ## -----------------------------------------------------------------------------
 data("multiple_experiments")
-length(multiple_experiments)
 
 ## -----------------------------------------------------------------------------
 head(multiple_experiments[[1]]$data)
@@ -63,14 +66,18 @@ print(multiple_experiments[[1]]$conditions)
 head(multiple_experiments[[2]]$data)
 print(multiple_experiments[[2]]$conditions)
 
+## -----------------------------------------------------------------------------
+data("arabian_tractors")
+head(arabian_tractors)
+
 ## -----------------------------------------------------------------------------
 my_model <- "modGompertz"
 
 ## -----------------------------------------------------------------------------
-my_pars <- list(logN0 = 2, C = 6, mu = .2, lambda = 25)
+my_pars <- list(logN0 = 2, C = 6, mu = .1, lambda = 50)
 
 ## -----------------------------------------------------------------------------
-my_time <- seq(0, 100, length = 1000)
+my_time <- seq(0, 200, length = 1000)
 
 ## -----------------------------------------------------------------------------
 static_prediction <- predict_isothermal_growth(my_model, my_time, my_pars)
@@ -89,21 +96,27 @@ plot(static_prediction) +
   theme_gray()
 
 ## -----------------------------------------------------------------------------
-my_conditions <- tibble(time = c(0, 5, 40),
+plot(static_prediction,
+     line_col = "darkgreen", line_size = 2, line_type = 3) +
+  xlab("Storage time (h)") +
+  ylab("Microbial count (log CFU/ml)") 
+
+## -----------------------------------------------------------------------------
+my_conditions <- tibble(Time = c(0, 5, 40),
                          temperature = c(20, 30, 35),
                          pH = c(7, 6.5, 5)
                          )
 
 ## -----------------------------------------------------------------------------
 ggplot(my_conditions) + 
-  geom_line(aes(x = time, y = temperature))
+  geom_line(aes(x = Time, y = temperature))
 
 ## -----------------------------------------------------------------------------
 ggplot(my_conditions) + 
-  geom_line(aes(x = time, y = pH))
+  geom_line(aes(x = Time, y = pH))
 
 ## -----------------------------------------------------------------------------
-my_primary <- list(mu_opt = 2,
+my_primary <- list(mu_opt = .9,
              Nmax = 1e8,
              N0 = 1e0,
              Q0 = 1e-3)
@@ -115,11 +128,11 @@ sec_temperature <- list(model = "Zwietering",
                         n = 1)
 
 ## -----------------------------------------------------------------------------
-sec_pH = list(model = "CPM",
-              xmin = 5.5,
-              xopt = 6.5,
-              xmax = 7.5,
-              n = 2)
+sec_pH <- list(model = "CPM",
+               xmin = 5.5,
+               xopt = 6.5,
+               xmax = 7.5,
+               n = 2)
 
 ## -----------------------------------------------------------------------------
 my_secondary <- list(
@@ -133,7 +146,8 @@ my_times <- seq(0, 50, length = 1000)
 ## -----------------------------------------------------------------------------
 dynamic_prediction <- predict_dynamic_growth(my_times,
                        my_conditions, my_primary,
-                       my_secondary)
+                       my_secondary,
+                       formula = . ~ Time)
 
 ## -----------------------------------------------------------------------------
 dynamic_prediction$simulation
@@ -145,8 +159,15 @@ plot(dynamic_prediction)
 plot(dynamic_prediction, add_factor = "temperature")
 
 ## -----------------------------------------------------------------------------
-plot(dynamic_prediction, add_factor = "temperature", ylims= c(0, 8), 
-     label_y1 = "Microbial count (log CFU/ml)", label_y2 = "Storage temperature (ºC)")
+plot(dynamic_prediction, 
+     add_factor = "temperature", 
+     ylims= c(0, 7), 
+     label_y1 = "Microbial count (log CFU/ml)", 
+     label_y2 = "Storage temperature (ºC)",
+     line_col = "lightgreen", 
+     line_size = 2, line_type2 = 1
+     ) +
+  xlab("Storage time (h)")
 
 ## -----------------------------------------------------------------------------
 time_to_logcount(static_prediction, 2.5)
@@ -159,7 +180,10 @@ time_to_logcount(dynamic_prediction, 10)
 
 ## -----------------------------------------------------------------------------
 my_data <- tibble(time = c(0, 25, 50, 75, 100),
-                  logN = c(2, 2.5, 7, 8, 8))
+                  log_size = c(2, 2.5, 7, 8, 8))
+
+## -----------------------------------------------------------------------------
+my_formula <- log_size ~ time
 
 ## -----------------------------------------------------------------------------
 my_model <- "Baranyi"
@@ -172,8 +196,9 @@ start = c(logNmax = 8, lambda = 25, logN0 = 2)
 
 ## -----------------------------------------------------------------------------
 static_fit <- fit_isothermal_growth(my_data, my_model,
-                      start, known
-                      )
+                                    start, known,
+                                    formula = my_formula
+                                    )
 
 ## -----------------------------------------------------------------------------
 summary(static_fit)
@@ -181,6 +206,10 @@ summary(static_fit)
 ## -----------------------------------------------------------------------------
 plot(static_fit)
 
+## -----------------------------------------------------------------------------
+plot(static_fit, 
+     line_size = 2, point_col = "lightblue", point_size = 5)
+
 ## -----------------------------------------------------------------------------
 data("example_cardinal")
 head(example_cardinal)
@@ -262,7 +291,11 @@ plot(my_dyna_fit)
 ## -----------------------------------------------------------------------------
 plot(my_dyna_fit, add_factor = "aw",
      label_y1 = "Log count (log CFU/ml)",
-     label_y2 = "Water activity")
+     label_y2 = "Water activity",
+     line_col = "pink",
+     line_col2 = "yellow",
+     point_col = "lightgreen") +
+  theme_dark()
 
 ## -----------------------------------------------------------------------------
 data("multiple_experiments")
@@ -303,39 +336,51 @@ plot(global_fit)
 ## ---- fig.width=7, fig.height=5-----------------------------------------------
 plot(global_fit, add_factor = "temperature")
 
-## -----------------------------------------------------------------------------
-my_model <- "Trilinear"
+## ---- fig.width=7, fig.height=5-----------------------------------------------
+plot(global_fit, add_factor = "temperature",
+     label_x = "Storage time (h)",
+     label_y1 = "Size of the population (log CFU/g)",
+     label_y2 = "Temperature (ºC)",
+     line_col = "maroon", line_size = 2,
+     line_type2 = 1, line_col2 = "darkgrey"
+     )
 
 ## -----------------------------------------------------------------------------
-my_times <- seq(0, 30, length = 100)
+my_model <- "modGompertz"
+
+## -----------------------------------------------------------------------------
+pars <- tribble(
+    ~par, ~mean, ~sd, ~scale,
+    "logN0", 0, .2, "original",
+    "mu", 2, .3, "sqrt",
+    "lambda", 4, .4, "log",
+    "C", 6, .5, "original"
+    )
+
+## -----------------------------------------------------------------------------
+my_times <- seq(0, 200, length = 100)
 
 ## -----------------------------------------------------------------------------
 n_sims <- 1000
 
 ## -----------------------------------------------------------------------------
-stoc_growth <- predict_stochastic_growth(my_model, my_times, n_sims,
-  mean_logN0 = 0, sd_logN0 = .2,
-  mean_sqmu = 2,sd_sqmu = .3,
-  mean_sqlambda = 4, sd_sqlambda = .4,
-  mean_logNmax = 6, sd_logNmax = .5)
+stoc_growth <- predict_stochastic_growth(my_model, my_times, n_sims, pars)
 
 ## -----------------------------------------------------------------------------
 plot(stoc_growth)
 
 ## -----------------------------------------------------------------------------
-my_cor <- matrix(c(1,   0,   0, 0,
-                   0,   1, 0.7, 0,
-                   0, 0.7,   1, 0,
-                   0,   0,   0, 1),
-                 nrow = 4)
+plot(stoc_growth, ribbon80_fill = "purple", ribbon90_fill = "pink", alpha80 = .8)
 
 ## -----------------------------------------------------------------------------
-stoc_growth2 <- predict_stochastic_growth(my_model, my_times, n_sims,
-  mean_logN0 = 0, sd_logN0 = .2,
-  mean_sqmu = 2,sd_sqmu = .3,
-  mean_sqlambda = 4, sd_sqlambda = .4,
-  mean_logNmax = 6, sd_logNmax = .5,
-  my_cor)
+my_cor <- matrix(c(1,   0,    0, 0,
+                   0,   1, -0.7, 0,
+                   0, -0.7,   1, 0,
+                   0,    0,   0, 1),
+                   nrow = 4)
+
+## -----------------------------------------------------------------------------
+stoc_growth2 <- predict_stochastic_growth(my_model, my_times, n_sims, pars, my_cor)
 
 plot(stoc_growth2)
 
@@ -374,7 +419,8 @@ summary(my_MCMC_fit)
 plot(my_MCMC_fit)
 
 ## -----------------------------------------------------------------------------
-plot(my_MCMC_fit, add_factor = "temperature")
+plot(my_MCMC_fit, add_factor = "temperature", 
+     point_col = "steelblue", point_shape = 2, point_size = 6)
 
 ## -----------------------------------------------------------------------------
 data("multiple_experiments")
@@ -400,17 +446,19 @@ set.seed(12412)
 global_MCMC <- fit_multiple_growth_MCMC(start, multiple_experiments, known, sec_names, 
                                         niter = 100,
                                         lower = c(.2, 29),  # lower limits of the model parameters
-                                        upper = c(.8, 34))  # upper limits of the model parameters
+                                        upper = c(1.6, 34))  # upper limits of the model parameters
 
 
 ## -----------------------------------------------------------------------------
 summary(global_MCMC)
 
-## -----------------------------------------------------------------------------
+## ---- fig.width = 7, fig.height=5---------------------------------------------
 plot(global_MCMC)
 
-## -----------------------------------------------------------------------------
-plot(global_MCMC, add_factor = "temperature")
+## ---- fig.width = 7, fig.height=5---------------------------------------------
+plot(global_MCMC, add_factor = "temperature",
+     line_col = "grey",
+     line_col2 = "blue", line_size2 = .5, line_type2 = 3)
 
 ## -----------------------------------------------------------------------------
 example_env_conditions
@@ -443,6 +491,17 @@ better_prediction <- predict_MCMC_growth(my_MCMC_fit,
 ## -----------------------------------------------------------------------------
 plot(better_prediction)
 
+## -----------------------------------------------------------------------------
+other_prediction <- predict_MCMC_growth(my_MCMC_fit, 
+                                        seq(0, 15, length = 100),
+                                        example_env_conditions, 
+                                        niter,
+                                        newpars = list(aw_xopt = .96,
+                                                        N0 = 10
+                                                        )
+                                         )
+plot(other_prediction)
+
 ## -----------------------------------------------------------------------------
 time_distrib <- distribution_to_logcount(stoc_growth, 4)
 
@@ -452,3 +511,6 @@ time_distrib$summary
 ## -----------------------------------------------------------------------------
 plot(time_distrib)
 
+## -----------------------------------------------------------------------------
+plot(time_distrib, bin_width = 2)
+
